summaryrefslogtreecommitdiff
path: root/src/driver.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/driver.h')
-rw-r--r--src/driver.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/driver.h b/src/driver.h
index 12ca4474d..af387b5d8 100644
--- a/src/driver.h
+++ b/src/driver.h
@@ -26,7 +26,7 @@ public:
/**
* Start this driver.
* @param parm Parameters passed to the driver.
* @return NULL if everything went okay, otherwise an error message.
*/
virtual const char *Start(const char * const *parm) = 0;
@@ -86,7 +86,7 @@ private:
*/
static Driver **GetActiveDriver(Driver::Type type)
{
- static Driver *s_driver[3] = { NULL, NULL, NULL };
+ static Driver *s_driver[3] = { nullptr, nullptr, nullptr };
return &s_driver[type];
}
@@ -116,7 +116,7 @@ public:
{
for (Driver::Type dt = Driver::DT_BEGIN; dt < Driver::DT_END; dt++) {
Driver *driver = *GetActiveDriver(dt);
- if (driver != NULL) driver->Stop();
+ if (driver != nullptr) driver->Stop();
}
}
@@ -26,7 +26,7 @@ public:
* Start this driver.
* @param parm Parameters passed to the driver.
- * @return NULL if everything went okay, otherwise an error message.
+ * @return nullptr if everything went okay, otherwise an error message.
*/
virtual const char *Start(const char * const *parm) = 0;